@@ -3,6 +3,7 @@ import coloredlogs
 import looker_sdk
 from .create_folder_permissions import create_folder_permissions as cfp
 from .create_user_permissions import user_permission as up
+from .create_user_attribute_permissions import create_ua_permissions as cuap
 from .utils import group_config as gc
 from .utils import folder_config as fc
 from .utils import parse_yaml as py
@@ -118,25 +119,28 @@ def main(**kwargs):
 
     logger.info(div)
 
+################################################################
+## User Attribute Config #######################################
+################################################################
+#    # # FIND UNIQUE USER ATTRIBUTES
+#    ua_metadata = cuap.get_user_attribute_metadata(
+#        sdk=sdk,
+#        parsed_yaml=instance_config)
+
+#    # # CREATE NEW FOLDERS
+
+#    cuap.create_user_attribute(
+#        sdk=sdk,
+#        ua_metadata=ua_metadata
+#    )
+
+#    # # CONFIGURE FOLDERS WITH EDIT AND VIEW ACCESS
+
+#    # # ADD AND SYNC CONTENT VIEW ACCESS WITH YAML
+
+#    # # DELETE ALL FOLDERS THAT DON'T MATCH WITH YAML
+
 
-    # # update content access
-    # logger.info(div)
-    # logger.info('Adding content access...')
-    # cfp.provision_folders_with_group_access(
-    #     sdk,
-    #     folder_permission_metadata=folder_permission_metadata)
-    # # create roles
-    # logger.info(div)
-    # logging.info('Creating Roles')
-    # role_metadata = up.create_role_mapping(group_config=group_config)
-    # role_create = up.create_roles(sdk=sdk, role_mapping=role_metadata)
-    # up.attach_role_to_group(sdk=sdk, role_metadata=role_create,
-    #                         group_config=group_config)
-    # # removing all user group from folders
-    # logger.info(div)
-    # logger.info('Removing all user group from folders')
-    # up.remove_all_user_group(
-    #     sdk=sdk, folder_permission_metadata=folder_permission_metadata)
 if __name__ == "__main__":
     YP = ('/usr/local/google/home/hugoselbie/code_sample/py/'
           'lmanage/tests/example_yamls/fullinstance.yaml')
